@@ -461,7 +461,7 @@ evalues.RD = function(n11, n10, n01, n00,
   # bias factor and E-value for point estimate
   est.BF = ( sqrt( (true + diff)^2 + 4 * p1 * p0 * f * (1-f)  ) - (true + diff) ) / ( 2 * p0 * f )
   est.Evalue    = threshold(est.BF)   
-  if( p1 - p0 <= true ) stop("For risk difference, true value must be greater than or equal to point estimate.")
+  if( p1 - p0 <= true ) stop("For risk difference, true value must be less than or equal to point estimate.")
   
   # compute lower CI limit
   Zalpha        = qnorm(1-alpha/2)  # critical value
@@ -990,8 +990,8 @@ sens_plot = function( type, q, muB=NA, Bmin=log(1), Bmax=log(5), sigB=0,
     }
     
     # compute values of g for the dual X-axis
-    if ( is.na(breaks.x1) ) breaks.x1 = seq( exp(Bmin), exp(Bmax), .5 )
-    if ( is.na(breaks.x2) ) breaks.x2 = round( breaks.x1 + sqrt( breaks.x1^2 - breaks.x1 ), 2)
+    if ( any( is.na(breaks.x1) ) ) breaks.x1 = seq( exp(Bmin), exp(Bmax), .5 )
+    if ( any( is.na(breaks.x2) ) ) breaks.x2 = round( breaks.x1 + sqrt( breaks.x1^2 - breaks.x1 ), 2)
     
     # define transformation in a way that is monotonic over the effective range of B (>1)
     # to avoid ggplot errors
